package com.qmth.data.docking.util.zufe;

import com.alibaba.fastjson.JSONObject;
import com.google.common.collect.ImmutableMap;
import com.google.common.collect.Maps;
import com.google.gson.reflect.TypeToken;
import com.qmth.boot.api.exception.ApiException;
import com.qmth.data.docking.bean.result.ZufeCourseResult;
import com.qmth.data.docking.bean.result.ZufeLoginResult;
import com.qmth.data.docking.entity.TSToken;
import com.qmth.data.docking.entity.YjxtKcxx;
import com.qmth.data.docking.service.TSTokenService;
import com.qmth.data.docking.service.YjxtKcxxService;
import com.qmth.data.docking.service.YjxtKsxxService;
import com.qmth.teachcloud.exchange.common.contant.SystemConstant;
import com.qmth.teachcloud.exchange.common.entity.BasicSchool;
import com.qmth.teachcloud.exchange.common.enums.ExceptionResultEnum;
import com.qmth.teachcloud.exchange.common.enums.FieldUniqueEnum;
import com.qmth.teachcloud.exchange.common.service.AuthInfoService;
import com.qmth.teachcloud.exchange.common.service.CommonCacheService;
import com.qmth.teachcloud.exchange.common.util.GsonUtil;
import com.qmth.teachcloud.exchange.common.util.HttpUtil;
import com.qmth.teachcloud.exchange.common.util.ResultUtil;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.BeanUtils;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @Description: 浙江财经大学数据同步工具类
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2025/6/10
 */
@Component
public class ZufeDataDockingUtil {
    private static final Logger log = LoggerFactory.getLogger(ZufeDataDockingUtil.class);

    @Resource
    AuthInfoService authInfoService;

    @Resource
    CommonCacheService commonCacheService;

    @Resource
    TSTokenService tokenService;

    @Resource
    YjxtKcxxService yjxtKcxxService;

    @Resource
    YjxtKsxxService yjxtKsxxService;

    public static final String SCHOOL_CODE = "zufe";

    /**
     * 浙江财经大学登录逻辑
     *
     * @param key
     * @param secret
     * @return
     */
    @Transactional
    public TSToken login(String key, String secret) throws IOException {
        TSToken tsTokenDb = null;
        try {
            log.info("login is come in");
            this.commonValidate();

            ImmutableMap params = new ImmutableMap.Builder<String, Object>().put("key", key)
                    .put("secret", secret).build();
            String result = HttpUtil.get(Constants.LOGIN_API_PATH, params, null, null);
//            result = "{\"code\":10000,\"message\":\"ok\",\"description\":\"api请求成功\",\"uuid\":\"cb070ebe7c314db0b55a05abc2236801\",\"result\":{\"access_token\":\"b87f0a72-b4eb-482c-8d14-55ef44fe4540\",\"token_type\":\"bearer\",\"refresh_token\":\"04431d30-e796-4fd3-9d41-391ad3f8376f\",\"expires_in\":5959,\"scope\":\"server\",\"license\":\"made by pangu\"}}";
            if (Objects.nonNull(result)) {
                log.info("login result:{}", result);
                JSONObject jsonObject = JSONObject.parseObject(result);
                String code = jsonObject.getString("code");
                String message = jsonObject.getString("message");
                if (Objects.equals(code, "10000") && Objects.equals(message, "ok")) {
                    ZufeLoginResult zufeLoginResult = GsonUtil.fromJson(jsonObject.getString("result"), ZufeLoginResult.class);
                    TSToken tsToken = new TSToken(zufeLoginResult, SCHOOL_CODE);
                    tsTokenDb = tokenService.findByCode(SCHOOL_CODE);
                    if (Objects.nonNull(tsTokenDb)) {
                        Long id = tsTokenDb.getId();
                        BeanUtils.copyProperties(tsToken, tsTokenDb);
                        tsTokenDb.updateTime(id);
                    } else {
                        tsTokenDb = new TSToken();
                        BeanUtils.copyProperties(tsToken, tsTokenDb);
                    }
                    tokenService.saveOrUpdate(tsTokenDb);
                }
            }
        } catch (Exception e) {
            log.error(SystemConstant.LOG_ERROR, e);
            if (e instanceof DuplicateKeyException) {
                String errorColumn = e.getCause().toString();
                String columnStr = errorColumn.substring(errorColumn.lastIndexOf("key") + 3, errorColumn.length()).replaceAll("'", "");
                throw ExceptionResultEnum.SQL_ERROR.exception("[" + FieldUniqueEnum.convertToTitle(columnStr) + "]数据不允许重复插入");
            } else if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        }
        return tsTokenDb;
    }

    /**
     * 浙江财经大学课程逻辑
     *
     * @param accessToken
     * @throws IOException
     */
    @Transactional
    public void course(String accessToken) throws IOException {
        try {
            log.info("course is come in");
            this.commonValidate();

            int page = SystemConstant.MIN_QUERY_SIZE, perPage = SystemConstant.MAX_QUERY_SIZE;
            Map<String, Object> params = Maps.newHashMap();
            params.put("accessToken", accessToken);
            params.put("page", page);
            params.put("per_page", perPage);
            List<ZufeCourseResult> zufeCourseResultAllList = new ArrayList<>();
            zufeCourseResultAllList = this.execCourseData(page, params, zufeCourseResultAllList);

            //数据比较
            if (!CollectionUtils.isEmpty(zufeCourseResultAllList)) {
                List<YjxtKcxx> yjxtKcxxList = yjxtKcxxService.list();
                if (!CollectionUtils.isEmpty(yjxtKcxxList)) {
                    Map<String, YjxtKcxx> yjxtKcxxMap = yjxtKcxxList.stream().collect(Collectors.toMap(m -> m.getCode(), Function.identity()));
                    for (ZufeCourseResult z : zufeCourseResultAllList) {
                        if (yjxtKcxxMap.containsKey(z.getKCH())) {
                            YjxtKcxx yjxtKcxx = new YjxtKcxx(z);
                            YjxtKcxx yjxtKcxxDb = yjxtKcxxMap.get(z.getKCH());
//                            if (Objects.equals("010010235", yjxtKcxx.getCode())) {
//                                yjxtKcxx.setName("基础会计1");
//                                yjxtKcxx.setCollegeName("会计学院（MPAcc学院）1");
//                            }
//                            if (Objects.equals("010030030", yjxtKcxx.getCode())) {
//                                yjxtKcxx.setName("中级财务会计2");
//                                yjxtKcxx.setCollegeName("会计学院（MPAcc学院）2");
//                            }
//                            if (Objects.equals("050110030", yjxtKcxx.getCode())) {
//                                yjxtKcxx.setName("Management Accounting（F2）3");
//                                yjxtKcxx.setCollegeName("会计学院（MPAcc学院）3");
//                            }
                            if (!yjxtKcxx.equals(yjxtKcxxDb)) {
                                yjxtKcxxDb.updateData(yjxtKcxx);
                            }
                        } else {
                            yjxtKcxxList.add(new YjxtKcxx(z));
                        }
                    }
                } else {
                    yjxtKcxxList = new ArrayList<>(zufeCourseResultAllList.size());
                    List<YjxtKcxx> finalYjxtKcxxList = yjxtKcxxList;
                    zufeCourseResultAllList.stream().peek(s -> {
                        finalYjxtKcxxList.add(new YjxtKcxx(s));
                    }).collect(Collectors.toList());
                }
                yjxtKcxxService.saveOrUpdateBatch(yjxtKcxxList);
            }
        } catch (Exception e) {
            log.error(SystemConstant.LOG_ERROR, e);
            if (e instanceof DuplicateKeyException) {
                String errorColumn = e.getCause().toString();
                String columnStr = errorColumn.substring(errorColumn.lastIndexOf("key") + 3, errorColumn.length()).replaceAll("'", "");
                throw ExceptionResultEnum.SQL_ERROR.exception("[" + FieldUniqueEnum.convertToTitle(columnStr) + "]数据不允许重复插入");
            } else if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        }
    }

    /**
     * 执行课程数据
     *
     * @param page
     * @param params
     * @param zufeCourseResultAllList
     * @return
     * @throws IOException
     */
    protected List<ZufeCourseResult> execCourseData(int page, Map<String, Object> params, List<ZufeCourseResult> zufeCourseResultAllList) throws IOException {
        String result = HttpUtil.get(Constants.COURSE_API_PATH, params, null, null);
//        result = "{\"code\":10000,\"message\":\"ok\",\"description\":\"api请求成功\",\"uuid\":\"babfa9f66d144e5a88221fda8c805a40\",\"result\":{\"page\":1,\"per\":500,\"total\":9234,\"max_page\":1,\"data_struct\":{\"KCH\":\"课程号\",\"KCMC\":\"课程名称\",\"KKXY\":\"开课学院\"},\"data\":[{\"KCH\":\"010010235\",\"KCMC\":\"基础会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010020030\",\"KCMC\":\"会计学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010020040\",\"KCMC\":\"会计学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010030030\",\"KCMC\":\"中级财务会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010030040\",\"KCMC\":\"中级财务会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010030050\",\"KCMC\":\"中级财务会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010040020\",\"KCMC\":\"高级财务会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010040030\",\"KCMC\":\"高级财务会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010050020\",\"KCMC\":\"成本会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010060020\",\"KCMC\":\"管理会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010060030\",\"KCMC\":\"管理会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010070225\",\"KCMC\":\"Excel在财会中的高级应用\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010080030\",\"KCMC\":\"管理会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010090020\",\"KCMC\":\"国际财务报告与分析（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"0101\",\"KCMC\":\"篮球\",\"KKXY\":\"体育部\"},{\"KCH\":\"010100020\",\"KCMC\":\"国际财务报告准则\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010110020\",\"KCMC\":\"国际会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010110030\",\"KCMC\":\"国际会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010120030\",\"KCMC\":\"会计理论\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010130020\",\"KCMC\":\"会计理论（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010130030\",\"KCMC\":\"会计理论（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010140020\",\"KCMC\":\"会计制度设计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010150020\",\"KCMC\":\"会计专题\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010160230\",\"KCMC\":\"网络会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010160240\",\"KCMC\":\"网络会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010170030\",\"KCMC\":\"法务会计学\",\"KKXY\":\"法学院\"},{\"KCH\":\"010180020\",\"KCMC\":\"法务会计专题\",\"KKXY\":\"法学院\"},{\"KCH\":\"010190020\",\"KCMC\":\"反倾销会计\",\"KKXY\":\"法学院\"},{\"KCH\":\"0102\",\"KCMC\":\"排球\",\"KKXY\":\"体育部\"},{\"KCH\":\"010200040\",\"KCMC\":\"成本管理会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010210035\",\"KCMC\":\"基础会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010220105\",\"KCMC\":\"基础会计实训\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010230040\",\"KCMC\":\"中级财务会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010230050\",\"KCMC\":\"中级财务会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010240230\",\"KCMC\":\"基础会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010250230\",\"KCMC\":\"基础会计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"010260230\",\"KCMC\":\"会计信息系统（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"0103\",\"KCMC\":\"足球\",\"KKXY\":\"体育部\"},{\"KCH\":\"0104\",\"KCMC\":\"网球\",\"KKXY\":\"体育部\"},{\"KCH\":\"0105\",\"KCMC\":\"乒乓球\",\"KKXY\":\"体育部\"},{\"KCH\":\"0106\",\"KCMC\":\"羽毛球\",\"KKXY\":\"体育部\"},{\"KCH\":\"0107\",\"KCMC\":\"健美操\",\"KKXY\":\"体育部\"},{\"KCH\":\"0108\",\"KCMC\":\"健身健美\",\"KKXY\":\"体育部\"},{\"KCH\":\"0109\",\"KCMC\":\"健身武术\",\"KKXY\":\"体育部\"},{\"KCH\":\"0110\",\"KCMC\":\"散打\",\"KKXY\":\"体育部\"},{\"KCH\":\"0111\",\"KCMC\":\"形体\",\"KKXY\":\"体育部\"},{\"KCH\":\"0112\",\"KCMC\":\"体育舞蹈\",\"KKXY\":\"体育部\"},{\"KCH\":\"0113\",\"KCMC\":\"保健班（专2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0200\",\"KCMC\":\"保健班（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"020010020\",\"KCMC\":\"财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020010030\",\"KCMC\":\"财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020010040\",\"KCMC\":\"财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020010245\",\"KCMC\":\"财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020020020\",\"KCMC\":\"财务分析\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020020030\",\"KCMC\":\"财务分析\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020020225\",\"KCMC\":\"财务分析\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020030020\",\"KCMC\":\"成本管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020030235\",\"KCMC\":\"成本管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020040020\",\"KCMC\":\"高级财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020040030\",\"KCMC\":\"高级财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020050020\",\"KCMC\":\"公司财务案例\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020060020\",\"KCMC\":\"管理咨询\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020070020\",\"KCMC\":\"国际财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020070030\",\"KCMC\":\"国际财务管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020080020\",\"KCMC\":\"内部控制\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020080030\",\"KCMC\":\"内部控制\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020090030\",\"KCMC\":\"财务舞弊检查\",\"KKXY\":\"法学院\"},{\"KCH\":\"0201\",\"KCMC\":\"篮球（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"020110030\",\"KCMC\":\"国际财务管理（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020120030\",\"KCMC\":\"工程财务\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020130030\",\"KCMC\":\"高级财务\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020150030\",\"KCMC\":\"财务会计基础（BA3-Fundamental Financial Accounting）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020160020\",\"KCMC\":\"组织管理（E1-Organizational Management）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020170030\",\"KCMC\":\"管理会计（P1-Management Accounting）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020180020\",\"KCMC\":\"高级管理会计（P2- Advanced Management Accounting）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020190030\",\"KCMC\":\"财务报告与税务（F1-Financial Reporting and Taxation）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"0202\",\"KCMC\":\"排球（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"020210030\",\"KCMC\":\"高级财务报告（F2-Advanced Financial Reporting）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020220020\",\"KCMC\":\"项目关系与管理（E2-Project and Relationship Management）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020230010\",\"KCMC\":\"CIMA案例-管理级\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020240030\",\"KCMC\":\"战略管理（E3-Strategic Management）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020260030\",\"KCMC\":\"财务战略（F3-Financial Strategy）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"020270010\",\"KCMC\":\"CIMA案例-战略级\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"0203\",\"KCMC\":\"足球（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0204\",\"KCMC\":\"网球（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0205\",\"KCMC\":\"乒乓球（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0206\",\"KCMC\":\"羽毛球（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0207\",\"KCMC\":\"健美操（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0208\",\"KCMC\":\"健身健美（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0210\",\"KCMC\":\"散打（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0211\",\"KCMC\":\"形体（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0212\",\"KCMC\":\"体育舞蹈（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0213\",\"KCMC\":\"跆拳道（1）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0300\",\"KCMC\":\"保健班（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"030010020\",\"KCMC\":\"审计学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030010030\",\"KCMC\":\"审计学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030010235\",\"KCMC\":\"审计学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030010250\",\"KCMC\":\"审计学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030020020\",\"KCMC\":\"各国审计制度与准则比较\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030030030\",\"KCMC\":\"国际审计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030040020\",\"KCMC\":\"国家审计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060010030\",\"KCMC\":\"资产评估学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060010235\",\"KCMC\":\"资产评估学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060020020\",\"KCMC\":\"金融资产评估\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060030020\",\"KCMC\":\"无形资产评估\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060040025\",\"KCMC\":\"资产评估案例\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060060020\",\"KCMC\":\"资产评估专题\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060070020\",\"KCMC\":\"公司治理与内部控制\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060080020\",\"KCMC\":\"资产管理学\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060090020\",\"KCMC\":\"企业价值评估\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"BUA1174\",\"KCMC\":\"企业管理决策方法和应用\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"060110020\",\"KCMC\":\"内部控制与风险管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060120020\",\"KCMC\":\"中外资产评估准则\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060130020\",\"KCMC\":\"中外资产评估准则与专题\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060140020\",\"KCMC\":\"国有资产管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"060150020\",\"KCMC\":\"资源性资产评估与管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"BUA1175\",\"KCMC\":\"数字化学习与人才发展\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"BUA1176\",\"KCMC\":\"经济社会调查\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"BUA1177\",\"KCMC\":\"Sales Technologies and Strategies\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"BUA1178\",\"KCMC\":\"创新管理前沿\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"BUA1179\",\"KCMC\":\"测验编制与实验研究方法\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"BUA1180\",\"KCMC\":\"全球商务模拟经营竞赛辅导\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"090010020\",\"KCMC\":\"财政学\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090010030\",\"KCMC\":\"财政学\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090020030\",\"KCMC\":\"财政学（双语）\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090020040\",\"KCMC\":\"财政学（双语）\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090030020\",\"KCMC\":\"地方财政学\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090040020\",\"KCMC\":\"公共支出分析\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090040030\",\"KCMC\":\"公共支出分析\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090050020\",\"KCMC\":\"公债经济学\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090070030\",\"KCMC\":\"公共经济学\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090080020\",\"KCMC\":\"中国财税史\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090080220\",\"KCMC\":\"中国财税史\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090090020\",\"KCMC\":\"财税政策分析\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090090220\",\"KCMC\":\"财税政策分析\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090090230\",\"KCMC\":\"财税政策分析\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090100030\",\"KCMC\":\"中外经济思想史\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"090110220\",\"KCMC\":\"创新创业专题\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100010020\",\"KCMC\":\"比较税制\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100020020\",\"KCMC\":\"国际税收\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100030020\",\"KCMC\":\"国际税收（双语）\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100030030\",\"KCMC\":\"国际税收（双语）\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100040215\",\"KCMC\":\"纳税检查\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100040220\",\"KCMC\":\"纳税检查\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100050030\",\"KCMC\":\"税法\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100060020\",\"KCMC\":\"税务筹划\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100060030\",\"KCMC\":\"税务筹划\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100070020\",\"KCMC\":\"税务管理\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100070225\",\"KCMC\":\"税务管理\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100080020\",\"KCMC\":\"税务会计\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100080220\",\"KCMC\":\"税务会计\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100090020\",\"KCMC\":\"中国税制\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100090030\",\"KCMC\":\"中国税制\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100110020\",\"KCMC\":\"纳税评估\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100120020\",\"KCMC\":\"税务代理实务\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"100140240\",\"KCMC\":\"高级税务\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120010020\",\"KCMC\":\"公共管理学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120010030\",\"KCMC\":\"公共管理学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120020020\",\"KCMC\":\"公共管制\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120020030\",\"KCMC\":\"公共管制\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120030020\",\"KCMC\":\"市政管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120040020\",\"KCMC\":\"政府预算\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120040030\",\"KCMC\":\"政府预算\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120050020\",\"KCMC\":\"公共政策学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120050030\",\"KCMC\":\"公共政策学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120050220\",\"KCMC\":\"公共政策学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120060020\",\"KCMC\":\"公共组织财务\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120060225\",\"KCMC\":\"公共组织财务\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120070030\",\"KCMC\":\"管理经济学（双语）\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120080020\",\"KCMC\":\"社区管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120090030\",\"KCMC\":\"非营利组织的战略营销\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120100030\",\"KCMC\":\"公共部门会计\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120100225\",\"KCMC\":\"公共部门会计\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120100230\",\"KCMC\":\"公共部门会计\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120110020\",\"KCMC\":\"公共部门绩效管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120110030\",\"KCMC\":\"公共部门绩效管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120110220\",\"KCMC\":\"公共部门绩效管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120120020\",\"KCMC\":\"公共管理专题\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120120030\",\"KCMC\":\"公共管理专题\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120130030\",\"KCMC\":\"地方公共政策分析\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120140030\",\"KCMC\":\"非营利组织管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120150020\",\"KCMC\":\"地方公共政策学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120150030\",\"KCMC\":\"地方公共政策学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120160230\",\"KCMC\":\"政府会计\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"120170020\",\"KCMC\":\"智慧城市建设与公共管理创新\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120180020\",\"KCMC\":\"公共组织绩效管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120190020\",\"KCMC\":\"公共项目管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120200020\",\"KCMC\":\"公共管理研究方法\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120200230\",\"KCMC\":\"公共管理研究方法\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120210020\",\"KCMC\":\"公共组织财务与会计\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120220020\",\"KCMC\":\"公共事业管理导论\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120230020\",\"KCMC\":\"创业与领导力\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"120240020\",\"KCMC\":\"批判式思维\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130010020\",\"KCMC\":\"社会保障学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130010030\",\"KCMC\":\"社会保障学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130020020\",\"KCMC\":\"福利经济学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130020030\",\"KCMC\":\"福利经济学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130030020\",\"KCMC\":\"比较社会保障制度\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130030030\",\"KCMC\":\"比较社会保障制度\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130040130\",\"KCMC\":\"管理定量分析\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130040225\",\"KCMC\":\"管理定量分析\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130050020\",\"KCMC\":\"劳动法与社会保障法规\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130050030\",\"KCMC\":\"劳动法与社会保障法规\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130060020\",\"KCMC\":\"劳动关系学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130060030\",\"KCMC\":\"劳动关系学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130070020\",\"KCMC\":\"劳动经济学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130080030\",\"KCMC\":\"劳动经济学（双语）\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130080040\",\"KCMC\":\"劳动经济学（双语）\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130090020\",\"KCMC\":\"人口经济学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130090030\",\"KCMC\":\"人口经济学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130100030\",\"KCMC\":\"社会保障基金管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130110020\",\"KCMC\":\"社会福利与救助\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130120020\",\"KCMC\":\"薪酬设计与管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130130020\",\"KCMC\":\"中国社会保障制度变迁\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130140030\",\"KCMC\":\"劳动与社会保障研究方法与应用\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130150030\",\"KCMC\":\"社会学导论\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130160020\",\"KCMC\":\"劳动经济与社会保障名著选读\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130170020\",\"KCMC\":\"医疗卫生经济学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130180020\",\"KCMC\":\"社会保障专业英语\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"130190020\",\"KCMC\":\"社会福利思想\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140010020\",\"KCMC\":\"行政管理学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140010030\",\"KCMC\":\"行政管理学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140020020\",\"KCMC\":\"行政管理学学科前沿\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140030030\",\"KCMC\":\"行政管理学原著选读（双语）\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140040020\",\"KCMC\":\"行政监察学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140050020\",\"KCMC\":\"行政领导学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140050030\",\"KCMC\":\"行政领导学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140060030\",\"KCMC\":\"行政思想史\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140070020\",\"KCMC\":\"行政文化学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140080020\",\"KCMC\":\"行政组织学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140080030\",\"KCMC\":\"行政组织学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140090020\",\"KCMC\":\"政府公共关系\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140100020\",\"KCMC\":\"政府危机管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140110020\",\"KCMC\":\"职业生涯管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140110220\",\"KCMC\":\"生涯规划专题\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"140120020\",\"KCMC\":\"当代中国政治制度\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140130020\",\"KCMC\":\"西方政治思想史\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140140020\",\"KCMC\":\"政治学原理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140140030\",\"KCMC\":\"政治学原理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140150020\",\"KCMC\":\"文秘学\",\"KKXY\":\"财政税务学院\"},{\"KCH\":\"140160020\",\"KCMC\":\"比较政府体制\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140170020\",\"KCMC\":\"地方政府学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140170030\",\"KCMC\":\"地方政府学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140180225\",\"KCMC\":\"电子政务A\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140190020\",\"KCMC\":\"公共部门人力资源管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140190030\",\"KCMC\":\"公共部门人力资源管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140200020\",\"KCMC\":\"公文写作与处理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140200030\",\"KCMC\":\"公文写作与处理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140210020\",\"KCMC\":\"国家公务员制度\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140220020\",\"KCMC\":\"社会政策\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140220030\",\"KCMC\":\"社会政策\",\"KKXY\":\"法学院\"},{\"KCH\":\"140230030\",\"KCMC\":\"市政学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140240020\",\"KCMC\":\"市政学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140250020\",\"KCMC\":\"行政案例与实务\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140250030\",\"KCMC\":\"行政案例与实务\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140260225\",\"KCMC\":\"电子政务B\",\"KKXY\":\"信息技术与人工智能学院\"},{\"KCH\":\"140270020\",\"KCMC\":\"电子政务概论\",\"KKXY\":\"信息技术与人工智能学院\"},{\"KCH\":\"140270225\",\"KCMC\":\"电子政务概论\",\"KKXY\":\"信息技术与人工智能学院\"},{\"KCH\":\"140280020\",\"KCMC\":\"公共危机管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140290020\",\"KCMC\":\"行政案例\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140300020\",\"KCMC\":\"比较行政学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140310030\",\"KCMC\":\"政府管理学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140320020\",\"KCMC\":\"中国政治制度\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140330020\",\"KCMC\":\"政府战略管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140340020\",\"KCMC\":\"行政领导与决策\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140350020\",\"KCMC\":\"公共组织行为学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140360020\",\"KCMC\":\"行政技术与方法\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140370020\",\"KCMC\":\"公共资源管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140380020\",\"KCMC\":\"产业管理学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140390030\",\"KCMC\":\"互联网监管与电子政务\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140400020\",\"KCMC\":\"社会管理学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140410020\",\"KCMC\":\"公共关系管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140420020\",\"KCMC\":\"文化事业管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140430020\",\"KCMC\":\"环境卫生管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"140440020\",\"KCMC\":\"教育行政管理\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"15\",\"KCMC\":\"国家二级刊物发表论文\",\"KKXY\":\"教务处、教师教学发展中心、通识教育中心\"},{\"KCH\":\"17\",\"KCMC\":\"ACM程序设计大赛\",\"KKXY\":\"教务处、教师教学发展中心、通识教育中心\"},{\"KCH\":\"170010020\",\"KCMC\":\"管理学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170010030\",\"KCMC\":\"管理学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170020120\",\"KCMC\":\"SPSS统计分析软件\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170020130\",\"KCMC\":\"SPSS统计分析软件\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170030020\",\"KCMC\":\"服务运行管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170050225\",\"KCMC\":\"管理统计学\",\"KKXY\":\"公共管理学院（MPA学院）\"},{\"KCH\":\"170060020\",\"KCMC\":\"国际企业管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170070020\",\"KCMC\":\"技术创新管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170080030\",\"KCMC\":\"跨国公司管理（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170090020\",\"KCMC\":\"企业管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170100215\",\"KCMC\":\"企业管理专题\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170110220\",\"KCMC\":\"商品学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170120220\",\"KCMC\":\"商务策划\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170130020\",\"KCMC\":\"研究与开发\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170140225\",\"KCMC\":\"运作管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170150030\",\"KCMC\":\"战略管理（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170170010\",\"KCMC\":\"管理学学科导论\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170180010\",\"KCMC\":\"研究方法与论文写作\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170190020\",\"KCMC\":\"跨国企业战略管理（双语）\",\"KKXY\":\"经济学院\"},{\"KCH\":\"170200020\",\"KCMC\":\"跨国公司与直接投资（双语）\",\"KKXY\":\"经济学院\"},{\"KCH\":\"170210020\",\"KCMC\":\"上市公司治理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170220030\",\"KCMC\":\"管理学（双语）\",\"KKXY\":\"经济学院\"},{\"KCH\":\"170230030\",\"KCMC\":\"运作管理（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170230230\",\"KCMC\":\"运作管理（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170240020\",\"KCMC\":\"管理沟通（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170240215\",\"KCMC\":\"管理沟通（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170250225\",\"KCMC\":\"管理统计\",\"KKXY\":\"数据科学学院\"},{\"KCH\":\"170260225\",\"KCMC\":\"企业运营管理\",\"KKXY\":\"信息技术与人工智能学院\"},{\"KCH\":\"170270230\",\"KCMC\":\"运营管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170280020\",\"KCMC\":\"战略管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"170290020\",\"KCMC\":\"东方管理学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180010020\",\"KCMC\":\"市场营销学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180010230\",\"KCMC\":\"市场营销学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180040020\",\"KCMC\":\"连锁经营与管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180040220\",\"KCMC\":\"连锁经营与管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180050010\",\"KCMC\":\"绿色营销专题\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180060220\",\"KCMC\":\"品牌管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180070230\",\"KCMC\":\"市场调查与分析\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180080120\",\"KCMC\":\"网络营销\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180090020\",\"KCMC\":\"消费行为学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180100220\",\"KCMC\":\"营销策划\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180120220\",\"KCMC\":\"营销管理前沿\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180130120\",\"KCMC\":\"营销实训\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180140220\",\"KCMC\":\"整合营销传播\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180150020\",\"KCMC\":\"营销学\",\"KKXY\":\"人文与传播学院\"},{\"KCH\":\"180150030\",\"KCMC\":\"营销学\",\"KKXY\":\"人文与传播学院\"},{\"KCH\":\"180160020\",\"KCMC\":\"实效促销\",\"KKXY\":\"人文与传播学院\"},{\"KCH\":\"180170030\",\"KCMC\":\"市场营销学（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180180030\",\"KCMC\":\"Professional Business Communication\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180190130\",\"KCMC\":\"商业数据分析（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180200010\",\"KCMC\":\"Career Development II\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180210030\",\"KCMC\":\"Managerial & Behavior Processes\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180220220\",\"KCMC\":\"商务谈判（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180230030\",\"KCMC\":\"Legal Environment of Business\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180240030\",\"KCMC\":\"Buyer behavior and Retail Marketing\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180250030\",\"KCMC\":\"Business Marketing\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180260030\",\"KCMC\":\"Senior Business Policy Forum\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180270030\",\"KCMC\":\"College Composition I\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180290030\",\"KCMC\":\"Professional Sales\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180300030\",\"KCMC\":\"Accounts and Territory Management\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180310030\",\"KCMC\":\"Interpersonal Communication\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180320030\",\"KCMC\":\"Sales Force Leadership\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180330030\",\"KCMC\":\"Advanced Sales\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180340020\",\"KCMC\":\"英语实践\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180341020\",\"KCMC\":\"英语实践（1）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180342020\",\"KCMC\":\"英语实践（2）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180370030\",\"KCMC\":\"Introduction to Business\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180380030\",\"KCMC\":\"Principle of Marketing\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180390030\",\"KCMC\":\"心理学导论\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180400030\",\"KCMC\":\"全球商务环境（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180410030\",\"KCMC\":\"Purchasing & Business Relationship Management\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180420030\",\"KCMC\":\"International Sales & Negotiation\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180430030\",\"KCMC\":\"Marketing Research & Data Management\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180440030\",\"KCMC\":\"Marketing Analysis & Decision Making\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180450020\",\"KCMC\":\"营销与公关\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180450030\",\"KCMC\":\"营销与公关\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180460020\",\"KCMC\":\"销售管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180470030\",\"KCMC\":\"Principales of Financial Management\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180480030\",\"KCMC\":\"Professional Business Writing\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180490030\",\"KCMC\":\"Sales Internship\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180510130\",\"KCMC\":\"商务统计学（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180520110\",\"KCMC\":\"新媒体营销\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180530030\",\"KCMC\":\"Buyer behavior and Relationship Marketing\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"180540010\",\"KCMC\":\"Career Development I\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190010020\",\"KCMC\":\"人力资源管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190010030\",\"KCMC\":\"人力资源管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190020020\",\"KCMC\":\"人本经济学\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190030215\",\"KCMC\":\"人力资源测评\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190030220\",\"KCMC\":\"人力资源测评\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190040215\",\"KCMC\":\"人力资源管理实务\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190050020\",\"KCMC\":\"人力资源管理专题\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190060020\",\"KCMC\":\"人力资源培训与开发\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190070020\",\"KCMC\":\"薪酬管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190070030\",\"KCMC\":\"薪酬管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190070230\",\"KCMC\":\"薪酬管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190080020\",\"KCMC\":\"员工关系管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190090020\",\"KCMC\":\"员工职业生涯管理\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"190100215\",\"KCMC\":\"招聘与录用\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"030040030\",\"KCMC\":\"国家审计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030050020\",\"KCMC\":\"基建审计基础\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030060020\",\"KCMC\":\"内部审计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030070020\",\"KCMC\":\"审计案例分析\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030070225\",\"KCMC\":\"审计案例分析\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030080020\",\"KCMC\":\"审计专题\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030090225\",\"KCMC\":\"网络审计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"0301\",\"KCMC\":\"篮球（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"030100030\",\"KCMC\":\"中国会计准则与会计制度\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030110235\",\"KCMC\":\"审计学（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"030120020\",\"KCMC\":\"内部审计与风险管理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"0302\",\"KCMC\":\"排球（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0303\",\"KCMC\":\"足球（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0304\",\"KCMC\":\"网球（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0305\",\"KCMC\":\"乒乓球（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0306\",\"KCMC\":\"羽毛球（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0307\",\"KCMC\":\"健美操（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0308\",\"KCMC\":\"健身健美（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0309\",\"KCMC\":\"健身武术（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0310\",\"KCMC\":\"散打（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0311\",\"KCMC\":\"形体（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0312\",\"KCMC\":\"体育舞蹈（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"0313\",\"KCMC\":\"跆拳道（2）\",\"KKXY\":\"体育部\"},{\"KCH\":\"BUA1181\",\"KCMC\":\"品牌思维与个人成长训练\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"BUA1182\",\"KCMC\":\"专业实践（1）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"04\",\"KCMC\":\"省财会信息化竞赛\",\"KKXY\":\"教务处、教师教学发展中心、通识教育中心\"},{\"KCH\":\"040010030\",\"KCMC\":\"财务管理（FN1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040010040\",\"KCMC\":\"财务管理（FN1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040020030\",\"KCMC\":\"成本会计（MA1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040030030\",\"KCMC\":\"高级财务会计（FA4）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040030040\",\"KCMC\":\"高级财务会计（FA4）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040040030\",\"KCMC\":\"高级管理会计（MA2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040050030\",\"KCMC\":\"会计理论（AT1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040060030\",\"KCMC\":\"基础会计（FA1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040060050\",\"KCMC\":\"基础会计（FA1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040060240\",\"KCMC\":\"基础会计（FA1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040060250\",\"KCMC\":\"基础会计（FA1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040070030\",\"KCMC\":\"审计学（AU1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040070235\",\"KCMC\":\"审计学（AU1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040081030\",\"KCMC\":\"中级财务会计（1）（FA2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040081040\",\"KCMC\":\"中级财务会计（1）（FA2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040082030\",\"KCMC\":\"中级财务会计（2）（FA3）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040082040\",\"KCMC\":\"中级财务会计（2）（FA3）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040090235\",\"KCMC\":\"管理信息系统（MS1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"BUA1184\",\"KCMC\":\"心理学导论（双语）\",\"KKXY\":\"管理学院（MBA学院）\"},{\"KCH\":\"040100235\",\"KCMC\":\"注册会计师执业实务（PA1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040110030\",\"KCMC\":\"高级财务管理（FN2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040120030\",\"KCMC\":\"高级审计学（AU2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040130030\",\"KCMC\":\"加拿大税法（TX1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040140025\",\"KCMC\":\"英语实践\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040140230\",\"KCMC\":\"英语实践\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040141020\",\"KCMC\":\"英语实践（1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040141025\",\"KCMC\":\"英语实践（1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040142020\",\"KCMC\":\"英语实践（2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040150040\",\"KCMC\":\"财务会计与报告（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040151030\",\"KCMC\":\"财务会计与报告（I）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040151040\",\"KCMC\":\"财务会计与报告（I）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040152030\",\"KCMC\":\"财务会计与报告（Ⅱ）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040153030\",\"KCMC\":\"财务会计与报告（Ⅲ）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040160030\",\"KCMC\":\"商业环境与概念（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040161030\",\"KCMC\":\"商业环境与概念（I）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040162030\",\"KCMC\":\"商业环境与概念（Ⅱ）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040171030\",\"KCMC\":\"法规（I）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040172030\",\"KCMC\":\"法规（Ⅱ）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040181030\",\"KCMC\":\"审计与鉴证（I）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040182030\",\"KCMC\":\"审计与鉴证（Ⅱ）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040190030\",\"KCMC\":\"AICPA综合实训\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040200030\",\"KCMC\":\"基础会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040200040\",\"KCMC\":\"基础会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040200050\",\"KCMC\":\"基础会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040211030\",\"KCMC\":\"中级财务会计（1）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040211040\",\"KCMC\":\"中级财务会计（1）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040222030\",\"KCMC\":\"中级财务会计（2）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040222040\",\"KCMC\":\"中级财务会计（2）（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040230030\",\"KCMC\":\"信息与技术（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040240030\",\"KCMC\":\"战略与治理（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040250030\",\"KCMC\":\"审计学（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040250040\",\"KCMC\":\"审计学（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040260030\",\"KCMC\":\"高级财务会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040260040\",\"KCMC\":\"高级财务会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040270030\",\"KCMC\":\"高级管理会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040280030\",\"KCMC\":\"高级财务管理（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040290230\",\"KCMC\":\"网络会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040300030\",\"KCMC\":\"税法（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040310030\",\"KCMC\":\"高级审计学（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040320030\",\"KCMC\":\"金融学（双语）\",\"KKXY\":\"金融学院\"},{\"KCH\":\"040330030\",\"KCMC\":\"外部财务报告（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040340030\",\"KCMC\":\"税收与商务决策（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040350030\",\"KCMC\":\"内部财务报告（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040360030\",\"KCMC\":\"法规（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040370030\",\"KCMC\":\"AICPA综合实训（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040380030\",\"KCMC\":\"成本会计（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040390030\",\"KCMC\":\"财务管理（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040390040\",\"KCMC\":\"财务管理（双语）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040400020\",\"KCMC\":\"财务报表分析\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040410030\",\"KCMC\":\"审计学原理\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040420020\",\"KCMC\":\"计算机审计\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040430130\",\"KCMC\":\"审计实务与实训\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040450030\",\"KCMC\":\"信息与技术（MS）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040460030\",\"KCMC\":\"管理会计（MA1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040470030\",\"KCMC\":\"Introductory Financial Accounting\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040480030\",\"KCMC\":\"Introductory Management Accounting\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040500030\",\"KCMC\":\"Intermediate Financial Reporting 1 \",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040510030\",\"KCMC\":\"Audit and Assurance\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040520030\",\"KCMC\":\"Intermediate Financial Reporting 2 \",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040540030\",\"KCMC\":\"Advanced Financial Reporting\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040550030\",\"KCMC\":\"Performance Management\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040560030\",\"KCMC\":\"Information Technology\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"040570030\",\"KCMC\":\"Taxation\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050010040\",\"KCMC\":\"Accountant in Business（F1）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050020030\",\"KCMC\":\"Advanced Financial Management（P4）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050020040\",\"KCMC\":\"Advanced Financial Management（P4）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050030030\",\"KCMC\":\"Advanced Performance Management（P5）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050040040\",\"KCMC\":\"Audit and Assurance（F8）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050040240\",\"KCMC\":\"Audit and Assurance（F8）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050050030\",\"KCMC\":\"Business  Analysis（P3）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050050040\",\"KCMC\":\"Business  Analysis（P3）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050060030\",\"KCMC\":\"Corporate and Business Law（F4）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050070040\",\"KCMC\":\"Corporate Reporting（P2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050070050\",\"KCMC\":\"Corporate Reporting（P2）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050080030\",\"KCMC\":\"Financial  Management（F9）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050090050\",\"KCMC\":\"Financial Accounting（F3）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050100040\",\"KCMC\":\"Financial Reporting（F7）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050100050\",\"KCMC\":\"Financial Reporting（F7）\",\"KKXY\":\"会计学院（MPAcc学院）\"},{\"KCH\":\"050110030\",\"KCMC\":\"Management Accounting（F2）\",\"KKXY\":\"会计学院（MPAcc学院）\"}],\"encrypted_field\":\"\"}}";
        if (Objects.nonNull(result)) {
            log.info("course result:{}", result);
            JSONObject jsonObject = JSONObject.parseObject(result);
            String code = jsonObject.getString("code");
            String message = jsonObject.getString("message");
            if (Objects.equals(code, "10000") && Objects.equals(message, "ok")) {
                JSONObject jsonObjectResult = jsonObject.getJSONObject("result");
                Integer total = jsonObjectResult.getInteger("total");
                Integer maxPage = jsonObjectResult.getInteger("max_page");
                if (Objects.nonNull(total) && total > 0 && Objects.nonNull(maxPage) && maxPage > 0) {
                    List<ZufeCourseResult> zufeCourseResultList = GsonUtil.fromJson(jsonObjectResult.getString("data"), new TypeToken<List<ZufeCourseResult>>() {
                    }.getType());
                    if (!CollectionUtils.isEmpty(zufeCourseResultList)) {
                        zufeCourseResultAllList.addAll(zufeCourseResultList);
                        while (page < maxPage.intValue()) {
                            page++;
                            params.put("page", page);
                            this.execCourseData(page, params, zufeCourseResultAllList);
                        }
                    }
                }
            }
        }
        return zufeCourseResultAllList;
    }

    /**
     * 浙江财经大学考试逻辑
     *
     * @param accessToken
     * @throws IOException
     */
    @Transactional
    public void exam(String accessToken) throws IOException {
        try{
            log.info("exam is come in");
            this.commonValidate();
        }catch(Exception e){
            log.error(SystemConstant.LOG_ERROR, e);
            if (e instanceof DuplicateKeyException) {
                String errorColumn = e.getCause().toString();
                String columnStr = errorColumn.substring(errorColumn.lastIndexOf("key") + 3, errorColumn.length()).replaceAll("'", "");
                throw ExceptionResultEnum.SQL_ERROR.exception("[" + FieldUniqueEnum.convertToTitle(columnStr) + "]数据不允许重复插入");
            } else if (e instanceof ApiException) {
                ResultUtil.error((ApiException) e, e.getMessage());
            } else {
                ResultUtil.error(e.getMessage());
            }
        }
    }

    /**
     * 公共校验
     */
    protected void commonValidate() {
        authInfoService.appHasExpired(SCHOOL_CODE);
        BasicSchool basicSchool = commonCacheService.schoolCache(SCHOOL_CODE);
        Objects.requireNonNull(basicSchool, "学校信息不存在");
    }
}
